# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.api.lookup_api import LookupApi


class TestLookupApi(unittest.TestCase):
    """LookupApi unit test stubs"""

    def setUp(self) -> None:
        self.api = LookupApi()

    def tearDown(self) -> None:
        pass

    def test_api_v1_lookup_environments_get(self) -> None:
        """Test case for api_v1_lookup_environments_get

        Get Environments
        """
        pass

    def test_api_v1_lookup_languages_get(self) -> None:
        """Test case for api_v1_lookup_languages_get

        Lookup Supported Languages
        """
        pass

    def test_api_v1_lookup_snippets_sync_post(self) -> None:
        """Test case for api_v1_lookup_snippets_sync_post

        Sync client snippets
        """
        pass

    def test_api_v1_lookup_states_code_get(self) -> None:
        """Test case for api_v1_lookup_states_code_get

        Get US State by Code
        """
        pass

    def test_api_v1_lookup_states_get(self) -> None:
        """Test case for api_v1_lookup_states_get

        Get US States
        """
        pass

    def test_api_v1_lookup_uids_get(self) -> None:
        """Test case for api_v1_lookup_uids_get

        Get legacy uids for matching knowledge data
        """
        pass

    def test_api_v1_lookup_user_roles_get(self) -> None:
        """Test case for api_v1_lookup_user_roles_get

        Get Possible User Roles
        """
        pass


if __name__ == '__main__':
    unittest.main()
