# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reports_report_artifact_list_response import ReportsReportArtifactListResponse

class TestReportsReportArtifactListResponse(unittest.TestCase):
    """ReportsReportArtifactListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportsReportArtifactListResponse:
        """Test ReportsReportArtifactListResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportsReportArtifactListResponse`
        """
        model = ReportsReportArtifactListResponse()
        if include_optional:
            return ReportsReportArtifactListResponse(
                data = [
                    neurograph.v1.models.reports/report_artifact_response.reports.ReportArtifactResponse(
                        ai_call_to_action = '', 
                        ai_generated_at = '', 
                        ai_key_highlights = [
                            ''
                            ], 
                        ai_main_insights = [
                            ''
                            ], 
                        client_id = 'cli_abc', 
                        created_by = '', 
                        description = '', 
                        embed_url = 'https://gamma.app/embed/...', 
                        error = '', 
                        executive_summary = '', 
                        id = '', 
                        key_stats = [
                            56
                            ], 
                        linked_concepts = [
                            ''
                            ], 
                        linked_kpis = [
                            neurograph.v1.models.reports/linked_kpi.reports.LinkedKPI(
                                change = '+0.4%', 
                                kpi_id = 'kpi_12345', 
                                kpi_name = 'Conversion Rate', 
                                trend = 'up', 
                                value = '3.2%', )
                            ], 
                        linked_queries = [
                            neurograph.v1.models.reports/linked_query.reports.LinkedQuery(
                                description = 'Products with highest conversion in Q4', 
                                query_id = 'qry_67890', 
                                query_name = 'Top Converting Products', )
                            ], 
                        linked_themes = [
                            ''
                            ], 
                        linked_topics = [
                            ''
                            ], 
                        markdown_content = '', 
                        markdown_updated_at = '', 
                        markdown_updated_by = '', 
                        metadata = [
                            56
                            ], 
                        name = 'Q4 2024 Persona Analysis', 
                        og_image_generated_at = '', 
                        og_image_url = '', 
                        og_image_version = 56, 
                        organization_id = '', 
                        pdf_url = '', 
                        presentation_url = 'https://gamma.app/docs/...', 
                        recommendations = [
                            neurograph.v1.models.reports/recommendation.reports.Recommendation(
                                action_url = '/campaigns/create?segment=a', 
                                category = 'engagement', 
                                id = '', 
                                priority = 'high', 
                                title = 'Increase email frequency for Segment A', )
                            ], 
                        report_type = 'monthly_persona_readout', 
                        thumbnail_url = '', 
                        ts_created = '', 
                        ts_updated = '', 
                        updated_by = '', )
                    ],
                error = '',
                limit = 56,
                page = 56,
                total = 56,
                total_pages = 56
            )
        else:
            return ReportsReportArtifactListResponse(
        )
        """

    def testReportsReportArtifactListResponse(self):
        """Test ReportsReportArtifactListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
