# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_model_insights_response import ReportingModelInsightsResponse

class TestReportingModelInsightsResponse(unittest.TestCase):
    """ReportingModelInsightsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingModelInsightsResponse:
        """Test ReportingModelInsightsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingModelInsightsResponse`
        """
        model = ReportingModelInsightsResponse()
        if include_optional:
            return ReportingModelInsightsResponse(
                cached = True,
                daily_predictions = [
                    neurograph.v1.models.reporting/daily_predictions.reporting.DailyPredictions(
                        date = '', 
                        total = 56, )
                    ],
                date_range = neurograph.v1.models.reporting/date_range.reporting.DateRange(
                    end_date = '', 
                    start_date = '', ),
                error = '',
                jobs_over_time = [
                    neurograph.v1.models.reporting/model_jobs_over_time.reporting.ModelJobsOverTime(
                        date = '', 
                        job_count = 56, 
                        model_type = '', )
                    ],
                query_time_ms = 56,
                recent_jobs = [
                    neurograph.v1.models.reporting/model_job_summary.reporting.ModelJobSummary(
                        active_build = 56, 
                        assignment_date = '', 
                        build_timestamp = '', 
                        client_id = '', 
                        client_name = '', 
                        job_id = '', 
                        model_type = '', 
                        model_version = '', 
                        org_name = '', 
                        prediction_count = 56, )
                    ],
                stats = neurograph.v1.models.reporting/model_job_stats.reporting.ModelJobStats(
                    active_builds = 56, 
                    latest_version = '', 
                    total_jobs = 56, 
                    total_predictions = 56, 
                    unique_versions = 56, ),
                version_stats = [
                    neurograph.v1.models.reporting/model_version_stats.reporting.ModelVersionStats(
                        job_count = 56, 
                        latest_build = '', 
                        model_version = '', )
                    ]
            )
        else:
            return ReportingModelInsightsResponse(
        )
        """

    def testReportingModelInsightsResponse(self):
        """Test ReportingModelInsightsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
