# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.pixel_client_pixel_details_response import PixelClientPixelDetailsResponse

class TestPixelClientPixelDetailsResponse(unittest.TestCase):
    """PixelClientPixelDetailsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PixelClientPixelDetailsResponse:
        """Test PixelClientPixelDetailsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PixelClientPixelDetailsResponse`
        """
        model = PixelClientPixelDetailsResponse()
        if include_optional:
            return PixelClientPixelDetailsResponse(
                cached = True,
                client_info = neurograph.v1.models.pixel/client_info.pixel.ClientInfo(
                    client_uid = '', 
                    domain = '', 
                    org_uid = '', ),
                daily_metrics = [
                    neurograph.v1.models.pixel/daily_client_pixel_metrics.pixel.DailyClientPixelMetrics(
                        avg_match_confidence = 1.337, 
                        avg_session_duration = 1.337, 
                        daily_cost = 1.337, 
                        date = '', 
                        enriched_visitors = 56, 
                        enrichment_rate_pct = 1.337, 
                        match_rate_pct = 1.337, 
                        matched_hems = 56, 
                        temporal_matches = 56, 
                        total_pageviews = 56, 
                        total_sessions = 56, 
                        unique_visitors = 56, 
                        vendor_matches = 56, )
                    ],
                date_range = neurograph.v1.models.pixel/date_range.pixel.DateRange(
                    end_date = '', 
                    start_date = '', ),
                enrichment_coverage = neurograph.v1.models.pixel/enrichment_coverage.pixel.EnrichmentCoverage(
                    email_valid_pct = 1.337, 
                    with_axon_id_pct = 1.337, 
                    with_company_pct = 1.337, 
                    with_email_pct = 1.337, 
                    with_industry_pct = 1.337, 
                    with_job_title_pct = 1.337, 
                    with_linkedin_pct = 1.337, 
                    with_name_pct = 1.337, 
                    with_phone_pct = 1.337, ),
                error = '',
                query_time_ms = 56,
                totals = neurograph.v1.models.pixel/client_pixel_totals.pixel.ClientPixelTotals(
                    avg_enrichment_rate_pct = 1.337, 
                    avg_match_rate_pct = 1.337, 
                    temporal_match_pct = 1.337, 
                    temporal_match_total = 56, 
                    total_enriched = 56, 
                    total_estimated_cost = 1.337, 
                    total_matched = 56, 
                    total_pageviews = 56, 
                    total_sessions = 56, 
                    total_visitors = 56, 
                    vendor_match_pct = 1.337, 
                    vendor_match_total = 56, )
            )
        else:
            return PixelClientPixelDetailsResponse(
        )
        """

    def testPixelClientPixelDetailsResponse(self):
        """Test PixelClientPixelDetailsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
