# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.dagster_info import DagsterInfo

class TestDagsterInfo(unittest.TestCase):
    """DagsterInfo unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DagsterInfo:
        """Test DagsterInfo
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DagsterInfo`
        """
        model = DagsterInfo()
        if include_optional:
            return DagsterInfo(
                id = 'dag_1234',
                job = 'initialize_personas_job',
                optional = 'some string, json, or whatever you want.',
                run = 'a8763df8-eec2-4856-8bf2-588cb49aa8b2',
                ts_created = 56
            )
        else:
            return DagsterInfo(
        )
        """

    def testDagsterInfo(self):
        """Test DagsterInfo"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
