# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_model_job_detail_response import ReportingModelJobDetailResponse

class TestReportingModelJobDetailResponse(unittest.TestCase):
    """ReportingModelJobDetailResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingModelJobDetailResponse:
        """Test ReportingModelJobDetailResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingModelJobDetailResponse`
        """
        model = ReportingModelJobDetailResponse()
        if include_optional:
            return ReportingModelJobDetailResponse(
                cached = True,
                error = '',
                job = neurograph.v1.models.reporting/model_job_detail.reporting.ModelJobDetail(
                    active_build = 56, 
                    assignment_date = '', 
                    build_timestamp = '', 
                    client_id = '', 
                    job_id = '', 
                    model_type = '', 
                    model_version = '', ),
                predictions = [
                    neurograph.v1.models.reporting/model_prediction.reporting.ModelPrediction(
                        account_id = '', 
                        assignment_date = '', 
                        persona_id = '', 
                        persona_name = '', 
                        prediction_id = '', )
                    ],
                query_time_ms = 56,
                total_predictions = 56
            )
        else:
            return ReportingModelJobDetailResponse(
        )
        """

    def testReportingModelJobDetailResponse(self):
        """Test ReportingModelJobDetailResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
