# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_buyer_scenario import ReportingBuyerScenario

class TestReportingBuyerScenario(unittest.TestCase):
    """ReportingBuyerScenario unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingBuyerScenario:
        """Test ReportingBuyerScenario
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingBuyerScenario`
        """
        model = ReportingBuyerScenario()
        if include_optional:
            return ReportingBuyerScenario(
                authored_boost = 1.337,
                blended_score = 1.337,
                cluster_boost = 1.337,
                cluster_ref_size = 56,
                cluster_size = 56,
                color = '',
                complexity = '',
                confidence = 1.337,
                description = '',
                diversity_factor = 1.337,
                final_score = 1.337,
                graph_paths = 56,
                graph_score = 1.337,
                graph_weight = 1.337,
                icon = '',
                intent = '',
                is_persona_authored = True,
                key_concepts = [
                    ''
                    ],
                market_concepts = [
                    neurograph.v1.models.reporting/scenario_market_concept.reporting.ScenarioMarketConcept(
                        concept_name = '', 
                        edge_type = '', 
                        link_source = '', 
                        similarity = 1.337, )
                    ],
                matched_products = 56,
                num_paths = 56,
                persona_context = '',
                primary_category = '',
                product_diversity = 1.337,
                product_paths = 56,
                product_score = 1.337,
                product_signal_count = 56,
                product_signal_gate = 1.337,
                purchase_likelihood = 1.337,
                relevance_pct = 1.337,
                scenario_name = '',
                scenario_resolved_id = '',
                scenario_type = '',
                scenario_variants = [
                    ''
                    ],
                shortest_path = 56,
                source_persona_id = '',
                tags = [
                    ''
                    ],
                timeline = '',
                top_paths = [
                    neurograph.v1.models.reporting/scenario_path.reporting.ScenarioPath(
                        edge_type = '', 
                        hops = 56, 
                        link_source = '', 
                        signal_source = '', 
                        similarity = 1.337, 
                        via_class = '', 
                        via_node = '', )
                    ],
                top_products = [
                    neurograph.v1.models.reporting/scenario_product.reporting.ScenarioProduct(
                        affinity_score = 1.337, 
                        affinity_tier = '', 
                        conversion_rate = 1.337, 
                        persona_purchase_pct = 1.337, 
                        product_name = '', 
                        product_type = '', 
                        purchase_pct_delta = 1.337, 
                        purchases = 56, )
                    ],
                trigger_event = ''
            )
        else:
            return ReportingBuyerScenario(
        )
        """

    def testReportingBuyerScenario(self):
        """Test ReportingBuyerScenario"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
