# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.organizations_theme_preset_list_response import OrganizationsThemePresetListResponse

class TestOrganizationsThemePresetListResponse(unittest.TestCase):
    """OrganizationsThemePresetListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OrganizationsThemePresetListResponse:
        """Test OrganizationsThemePresetListResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OrganizationsThemePresetListResponse`
        """
        model = OrganizationsThemePresetListResponse()
        if include_optional:
            return OrganizationsThemePresetListResponse(
                error = '',
                presets = [
                    neurograph.v1.models.organizations/theme_preset_response.organizations.ThemePresetResponse(
                        category = '', 
                        color1 = '', 
                        color2 = '', 
                        color3 = '', 
                        color4 = '', 
                        color5 = '', 
                        created_at = '', 
                        description = '', 
                        error = '', 
                        id = 56, 
                        is_active = True, 
                        is_system = True, 
                        name = '', 
                        preview_url = '', 
                        primary_color = '', 
                        secondary_color = '', 
                        tags = [
                            ''
                            ], 
                        tertiary_color = '', 
                        updated_at = '', )
                    ],
                total = 56
            )
        else:
            return OrganizationsThemePresetListResponse(
        )
        """

    def testOrganizationsThemePresetListResponse(self):
        """Test OrganizationsThemePresetListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
