# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.organizations_preview_branding_response import OrganizationsPreviewBrandingResponse

class TestOrganizationsPreviewBrandingResponse(unittest.TestCase):
    """OrganizationsPreviewBrandingResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OrganizationsPreviewBrandingResponse:
        """Test OrganizationsPreviewBrandingResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OrganizationsPreviewBrandingResponse`
        """
        model = OrganizationsPreviewBrandingResponse()
        if include_optional:
            return OrganizationsPreviewBrandingResponse(
                accessibility_score = 56,
                error = '',
                tokens_dark = [
                    56
                    ],
                tokens_light = [
                    56
                    ],
                validation_warnings = {
                    'key' : [
                        ''
                        ]
                    }
            )
        else:
            return OrganizationsPreviewBrandingResponse(
        )
        """

    def testOrganizationsPreviewBrandingResponse(self):
        """Test OrganizationsPreviewBrandingResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
