# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.client_system_healthcheck_v2_snapshot import ClientSystemHealthcheckV2Snapshot

class TestClientSystemHealthcheckV2Snapshot(unittest.TestCase):
    """ClientSystemHealthcheckV2Snapshot unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ClientSystemHealthcheckV2Snapshot:
        """Test ClientSystemHealthcheckV2Snapshot
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ClientSystemHealthcheckV2Snapshot`
        """
        model = ClientSystemHealthcheckV2Snapshot()
        if include_optional:
            return ClientSystemHealthcheckV2Snapshot(
                client_id = '',
                client_name = '',
                client_uid = '',
                error_json = [
                    56
                    ],
                error_message = '',
                graph_json = [
                    56
                    ],
                graph_version = 56,
                id = '',
                integration_mode = '',
                metrics_json = [
                    56
                    ],
                org_id = '',
                org_name = '',
                org_uid = '',
                result_success = True,
                run_date = '',
                status = '',
                summary_json = [
                    56
                    ],
                ts_finished = '',
                ts_started = ''
            )
        else:
            return ClientSystemHealthcheckV2Snapshot(
        )
        """

    def testClientSystemHealthcheckV2Snapshot(self):
        """Test ClientSystemHealthcheckV2Snapshot"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
