# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.organizations_gamma_theme_request import OrganizationsGammaThemeRequest

class TestOrganizationsGammaThemeRequest(unittest.TestCase):
    """OrganizationsGammaThemeRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OrganizationsGammaThemeRequest:
        """Test OrganizationsGammaThemeRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OrganizationsGammaThemeRequest`
        """
        model = OrganizationsGammaThemeRequest()
        if include_optional:
            return OrganizationsGammaThemeRequest(
                accent_color = '#0CB04A',
                background_color = '#F7F8FA',
                border_color = '#D3D9E0',
                brand_personality = 'professional, innovative, trustworthy',
                brand_reasoning = 'Professional color palette with high contrast',
                brand_style = 'Modern, Professional',
                industry = 'E-commerce',
                primary_color = '#0E5B33',
                secondary_color = '#F28B30',
                source_url = 'https://example.com',
                surface_color = '#FFFFFF',
                target_audience = 'Enterprise customers',
                text_color = '#111111',
                text_secondary_color = '#5E6B78'
            )
        else:
            return OrganizationsGammaThemeRequest(
        )
        """

    def testOrganizationsGammaThemeRequest(self):
        """Test OrganizationsGammaThemeRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
